# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['OvhcloudConnectPopConfigArgs', 'OvhcloudConnectPopConfig']

@pulumi.input_type
class OvhcloudConnectPopConfigArgs:
    def __init__(__self__, *,
                 interface_id: pulumi.Input[builtins.float],
                 service_name: pulumi.Input[builtins.str],
                 type: pulumi.Input[builtins.str],
                 customer_bgp_area: Optional[pulumi.Input[builtins.float]] = None,
                 ovh_bgp_area: Optional[pulumi.Input[builtins.float]] = None,
                 subnet: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a OvhcloudConnectPopConfig resource.
        :param pulumi.Input[builtins.float] interface_id: ID of the interface
        :param pulumi.Input[builtins.str] service_name: Service name
        :param pulumi.Input[builtins.str] type: Type of the pop configuration
        :param pulumi.Input[builtins.float] customer_bgp_area: Customer Private AS
        :param pulumi.Input[builtins.float] ovh_bgp_area: OVH Private AS
        :param pulumi.Input[builtins.str] subnet: Subnet should be a /30, first IP for OVH, second IP for customer
        """
        pulumi.set(__self__, "interface_id", interface_id)
        pulumi.set(__self__, "service_name", service_name)
        pulumi.set(__self__, "type", type)
        if customer_bgp_area is not None:
            pulumi.set(__self__, "customer_bgp_area", customer_bgp_area)
        if ovh_bgp_area is not None:
            pulumi.set(__self__, "ovh_bgp_area", ovh_bgp_area)
        if subnet is not None:
            pulumi.set(__self__, "subnet", subnet)

    @property
    @pulumi.getter(name="interfaceId")
    def interface_id(self) -> pulumi.Input[builtins.float]:
        """
        ID of the interface
        """
        return pulumi.get(self, "interface_id")

    @interface_id.setter
    def interface_id(self, value: pulumi.Input[builtins.float]):
        pulumi.set(self, "interface_id", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[builtins.str]:
        """
        Service name
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[builtins.str]:
        """
        Type of the pop configuration
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="customerBgpArea")
    def customer_bgp_area(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        Customer Private AS
        """
        return pulumi.get(self, "customer_bgp_area")

    @customer_bgp_area.setter
    def customer_bgp_area(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "customer_bgp_area", value)

    @property
    @pulumi.getter(name="ovhBgpArea")
    def ovh_bgp_area(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        OVH Private AS
        """
        return pulumi.get(self, "ovh_bgp_area")

    @ovh_bgp_area.setter
    def ovh_bgp_area(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "ovh_bgp_area", value)

    @property
    @pulumi.getter
    def subnet(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Subnet should be a /30, first IP for OVH, second IP for customer
        """
        return pulumi.get(self, "subnet")

    @subnet.setter
    def subnet(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "subnet", value)


@pulumi.input_type
class _OvhcloudConnectPopConfigState:
    def __init__(__self__, *,
                 customer_bgp_area: Optional[pulumi.Input[builtins.float]] = None,
                 interface_id: Optional[pulumi.Input[builtins.float]] = None,
                 ovh_bgp_area: Optional[pulumi.Input[builtins.float]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 subnet: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering OvhcloudConnectPopConfig resources.
        :param pulumi.Input[builtins.float] customer_bgp_area: Customer Private AS
        :param pulumi.Input[builtins.float] interface_id: ID of the interface
        :param pulumi.Input[builtins.float] ovh_bgp_area: OVH Private AS
        :param pulumi.Input[builtins.str] service_name: Service name
        :param pulumi.Input[builtins.str] status: Status of the pop configuration
        :param pulumi.Input[builtins.str] subnet: Subnet should be a /30, first IP for OVH, second IP for customer
        :param pulumi.Input[builtins.str] type: Type of the pop configuration
        """
        if customer_bgp_area is not None:
            pulumi.set(__self__, "customer_bgp_area", customer_bgp_area)
        if interface_id is not None:
            pulumi.set(__self__, "interface_id", interface_id)
        if ovh_bgp_area is not None:
            pulumi.set(__self__, "ovh_bgp_area", ovh_bgp_area)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if subnet is not None:
            pulumi.set(__self__, "subnet", subnet)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="customerBgpArea")
    def customer_bgp_area(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        Customer Private AS
        """
        return pulumi.get(self, "customer_bgp_area")

    @customer_bgp_area.setter
    def customer_bgp_area(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "customer_bgp_area", value)

    @property
    @pulumi.getter(name="interfaceId")
    def interface_id(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        ID of the interface
        """
        return pulumi.get(self, "interface_id")

    @interface_id.setter
    def interface_id(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "interface_id", value)

    @property
    @pulumi.getter(name="ovhBgpArea")
    def ovh_bgp_area(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        OVH Private AS
        """
        return pulumi.get(self, "ovh_bgp_area")

    @ovh_bgp_area.setter
    def ovh_bgp_area(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "ovh_bgp_area", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Service name
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Status of the pop configuration
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def subnet(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Subnet should be a /30, first IP for OVH, second IP for customer
        """
        return pulumi.get(self, "subnet")

    @subnet.setter
    def subnet(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "subnet", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Type of the pop configuration
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("ovh:index/ovhcloudConnectPopConfig:OvhcloudConnectPopConfig")
class OvhcloudConnectPopConfig(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 customer_bgp_area: Optional[pulumi.Input[builtins.float]] = None,
                 interface_id: Optional[pulumi.Input[builtins.float]] = None,
                 ovh_bgp_area: Optional[pulumi.Input[builtins.float]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 subnet: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Creates a pop configuration for an Ovhcloud Connect product.

        Please take a look at the list of available `types` in the `Required` section in order to know the list of available type configurations.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        occ = ovh.OVHcloud.connect(service_name="XXX")
        pop = ovh.OvhcloudConnectPopConfig("pop",
            service_name=occ.service_name,
            interface_id=occ.interface_lists[0],
            type="l3",
            customer_bgp_area=65400,
            ovh_bgp_area=65401,
            subnet="I.I.I.I/30")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.float] customer_bgp_area: Customer Private AS
        :param pulumi.Input[builtins.float] interface_id: ID of the interface
        :param pulumi.Input[builtins.float] ovh_bgp_area: OVH Private AS
        :param pulumi.Input[builtins.str] service_name: Service name
        :param pulumi.Input[builtins.str] subnet: Subnet should be a /30, first IP for OVH, second IP for customer
        :param pulumi.Input[builtins.str] type: Type of the pop configuration
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: OvhcloudConnectPopConfigArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a pop configuration for an Ovhcloud Connect product.

        Please take a look at the list of available `types` in the `Required` section in order to know the list of available type configurations.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        occ = ovh.OVHcloud.connect(service_name="XXX")
        pop = ovh.OvhcloudConnectPopConfig("pop",
            service_name=occ.service_name,
            interface_id=occ.interface_lists[0],
            type="l3",
            customer_bgp_area=65400,
            ovh_bgp_area=65401,
            subnet="I.I.I.I/30")
        ```

        :param str resource_name: The name of the resource.
        :param OvhcloudConnectPopConfigArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(OvhcloudConnectPopConfigArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 customer_bgp_area: Optional[pulumi.Input[builtins.float]] = None,
                 interface_id: Optional[pulumi.Input[builtins.float]] = None,
                 ovh_bgp_area: Optional[pulumi.Input[builtins.float]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 subnet: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = OvhcloudConnectPopConfigArgs.__new__(OvhcloudConnectPopConfigArgs)

            __props__.__dict__["customer_bgp_area"] = customer_bgp_area
            if interface_id is None and not opts.urn:
                raise TypeError("Missing required property 'interface_id'")
            __props__.__dict__["interface_id"] = interface_id
            __props__.__dict__["ovh_bgp_area"] = ovh_bgp_area
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            __props__.__dict__["subnet"] = subnet
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            __props__.__dict__["status"] = None
        super(OvhcloudConnectPopConfig, __self__).__init__(
            'ovh:index/ovhcloudConnectPopConfig:OvhcloudConnectPopConfig',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            customer_bgp_area: Optional[pulumi.Input[builtins.float]] = None,
            interface_id: Optional[pulumi.Input[builtins.float]] = None,
            ovh_bgp_area: Optional[pulumi.Input[builtins.float]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            subnet: Optional[pulumi.Input[builtins.str]] = None,
            type: Optional[pulumi.Input[builtins.str]] = None) -> 'OvhcloudConnectPopConfig':
        """
        Get an existing OvhcloudConnectPopConfig resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.float] customer_bgp_area: Customer Private AS
        :param pulumi.Input[builtins.float] interface_id: ID of the interface
        :param pulumi.Input[builtins.float] ovh_bgp_area: OVH Private AS
        :param pulumi.Input[builtins.str] service_name: Service name
        :param pulumi.Input[builtins.str] status: Status of the pop configuration
        :param pulumi.Input[builtins.str] subnet: Subnet should be a /30, first IP for OVH, second IP for customer
        :param pulumi.Input[builtins.str] type: Type of the pop configuration
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _OvhcloudConnectPopConfigState.__new__(_OvhcloudConnectPopConfigState)

        __props__.__dict__["customer_bgp_area"] = customer_bgp_area
        __props__.__dict__["interface_id"] = interface_id
        __props__.__dict__["ovh_bgp_area"] = ovh_bgp_area
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["status"] = status
        __props__.__dict__["subnet"] = subnet
        __props__.__dict__["type"] = type
        return OvhcloudConnectPopConfig(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="customerBgpArea")
    def customer_bgp_area(self) -> pulumi.Output[builtins.float]:
        """
        Customer Private AS
        """
        return pulumi.get(self, "customer_bgp_area")

    @property
    @pulumi.getter(name="interfaceId")
    def interface_id(self) -> pulumi.Output[builtins.float]:
        """
        ID of the interface
        """
        return pulumi.get(self, "interface_id")

    @property
    @pulumi.getter(name="ovhBgpArea")
    def ovh_bgp_area(self) -> pulumi.Output[builtins.float]:
        """
        OVH Private AS
        """
        return pulumi.get(self, "ovh_bgp_area")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        Service name
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Status of the pop configuration
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def subnet(self) -> pulumi.Output[builtins.str]:
        """
        Subnet should be a /30, first IP for OVH, second IP for customer
        """
        return pulumi.get(self, "subnet")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[builtins.str]:
        """
        Type of the pop configuration
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetM3dbNamespaceResult',
    'AwaitableGetM3dbNamespaceResult',
    'get_m3db_namespace',
    'get_m3db_namespace_output',
]

@pulumi.output_type
class GetM3dbNamespaceResult:
    """
    A collection of values returned by getM3dbNamespace.
    """
    def __init__(__self__, cluster_id=None, id=None, name=None, resolution=None, retention_block_data_expiration_duration=None, retention_block_size_duration=None, retention_buffer_future_duration=None, retention_buffer_past_duration=None, retention_period_duration=None, service_name=None, snapshot_enabled=None, type=None, writes_to_commit_log_enabled=None):
        if cluster_id and not isinstance(cluster_id, str):
            raise TypeError("Expected argument 'cluster_id' to be a str")
        pulumi.set(__self__, "cluster_id", cluster_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if resolution and not isinstance(resolution, str):
            raise TypeError("Expected argument 'resolution' to be a str")
        pulumi.set(__self__, "resolution", resolution)
        if retention_block_data_expiration_duration and not isinstance(retention_block_data_expiration_duration, str):
            raise TypeError("Expected argument 'retention_block_data_expiration_duration' to be a str")
        pulumi.set(__self__, "retention_block_data_expiration_duration", retention_block_data_expiration_duration)
        if retention_block_size_duration and not isinstance(retention_block_size_duration, str):
            raise TypeError("Expected argument 'retention_block_size_duration' to be a str")
        pulumi.set(__self__, "retention_block_size_duration", retention_block_size_duration)
        if retention_buffer_future_duration and not isinstance(retention_buffer_future_duration, str):
            raise TypeError("Expected argument 'retention_buffer_future_duration' to be a str")
        pulumi.set(__self__, "retention_buffer_future_duration", retention_buffer_future_duration)
        if retention_buffer_past_duration and not isinstance(retention_buffer_past_duration, str):
            raise TypeError("Expected argument 'retention_buffer_past_duration' to be a str")
        pulumi.set(__self__, "retention_buffer_past_duration", retention_buffer_past_duration)
        if retention_period_duration and not isinstance(retention_period_duration, str):
            raise TypeError("Expected argument 'retention_period_duration' to be a str")
        pulumi.set(__self__, "retention_period_duration", retention_period_duration)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if snapshot_enabled and not isinstance(snapshot_enabled, bool):
            raise TypeError("Expected argument 'snapshot_enabled' to be a bool")
        pulumi.set(__self__, "snapshot_enabled", snapshot_enabled)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if writes_to_commit_log_enabled and not isinstance(writes_to_commit_log_enabled, bool):
            raise TypeError("Expected argument 'writes_to_commit_log_enabled' to be a bool")
        pulumi.set(__self__, "writes_to_commit_log_enabled", writes_to_commit_log_enabled)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> builtins.str:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def resolution(self) -> builtins.str:
        """
        Resolution for an aggregated namespace.
        """
        return pulumi.get(self, "resolution")

    @property
    @pulumi.getter(name="retentionBlockDataExpirationDuration")
    def retention_block_data_expiration_duration(self) -> builtins.str:
        """
        Controls how long we wait before expiring stale data.
        """
        return pulumi.get(self, "retention_block_data_expiration_duration")

    @property
    @pulumi.getter(name="retentionBlockSizeDuration")
    def retention_block_size_duration(self) -> builtins.str:
        """
        Controls how long to keep a block in memory before flushing to a fileset on disk.
        """
        return pulumi.get(self, "retention_block_size_duration")

    @property
    @pulumi.getter(name="retentionBufferFutureDuration")
    def retention_buffer_future_duration(self) -> builtins.str:
        """
        Controls how far into the future writes to the namespace will be accepted.
        """
        return pulumi.get(self, "retention_buffer_future_duration")

    @property
    @pulumi.getter(name="retentionBufferPastDuration")
    def retention_buffer_past_duration(self) -> builtins.str:
        """
        Controls how far into the past writes to the namespace will be accepted.
        """
        return pulumi.get(self, "retention_buffer_past_duration")

    @property
    @pulumi.getter(name="retentionPeriodDuration")
    def retention_period_duration(self) -> builtins.str:
        """
        Controls the duration of time that M3DB will retain data for the namespace.
        """
        return pulumi.get(self, "retention_period_duration")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter(name="snapshotEnabled")
    def snapshot_enabled(self) -> builtins.bool:
        """
        SDefines whether M3db will create snapshot files for this namespace.
        """
        return pulumi.get(self, "snapshot_enabled")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        Type of namespace.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="writesToCommitLogEnabled")
    def writes_to_commit_log_enabled(self) -> builtins.bool:
        """
        Defines whether M3DB will include writes to this namespace in the commit log.
        """
        return pulumi.get(self, "writes_to_commit_log_enabled")


class AwaitableGetM3dbNamespaceResult(GetM3dbNamespaceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetM3dbNamespaceResult(
            cluster_id=self.cluster_id,
            id=self.id,
            name=self.name,
            resolution=self.resolution,
            retention_block_data_expiration_duration=self.retention_block_data_expiration_duration,
            retention_block_size_duration=self.retention_block_size_duration,
            retention_buffer_future_duration=self.retention_buffer_future_duration,
            retention_buffer_past_duration=self.retention_buffer_past_duration,
            retention_period_duration=self.retention_period_duration,
            service_name=self.service_name,
            snapshot_enabled=self.snapshot_enabled,
            type=self.type,
            writes_to_commit_log_enabled=self.writes_to_commit_log_enabled)


def get_m3db_namespace(cluster_id: Optional[builtins.str] = None,
                       name: Optional[builtins.str] = None,
                       service_name: Optional[builtins.str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetM3dbNamespaceResult:
    """
    Use this data source to get information about a namespace of a M3DB cluster associated with a public cloud project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    m3db_namespace = ovh.CloudProject.get_m3db_namespace(service_name="XXX",
        cluster_id="YYY",
        name="ZZZ")
    pulumi.export("m3dbnamespaceType", m3db_namespace.type)
    ```


    :param builtins.str cluster_id: Cluster ID
    :param builtins.str name: Name of the namespace.
    :param builtins.str service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    """
    __args__ = dict()
    __args__['clusterId'] = cluster_id
    __args__['name'] = name
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:CloudProject/getM3dbNamespace:getM3dbNamespace', __args__, opts=opts, typ=GetM3dbNamespaceResult).value

    return AwaitableGetM3dbNamespaceResult(
        cluster_id=pulumi.get(__ret__, 'cluster_id'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        resolution=pulumi.get(__ret__, 'resolution'),
        retention_block_data_expiration_duration=pulumi.get(__ret__, 'retention_block_data_expiration_duration'),
        retention_block_size_duration=pulumi.get(__ret__, 'retention_block_size_duration'),
        retention_buffer_future_duration=pulumi.get(__ret__, 'retention_buffer_future_duration'),
        retention_buffer_past_duration=pulumi.get(__ret__, 'retention_buffer_past_duration'),
        retention_period_duration=pulumi.get(__ret__, 'retention_period_duration'),
        service_name=pulumi.get(__ret__, 'service_name'),
        snapshot_enabled=pulumi.get(__ret__, 'snapshot_enabled'),
        type=pulumi.get(__ret__, 'type'),
        writes_to_commit_log_enabled=pulumi.get(__ret__, 'writes_to_commit_log_enabled'))
def get_m3db_namespace_output(cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                              name: Optional[pulumi.Input[builtins.str]] = None,
                              service_name: Optional[pulumi.Input[builtins.str]] = None,
                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetM3dbNamespaceResult]:
    """
    Use this data source to get information about a namespace of a M3DB cluster associated with a public cloud project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    m3db_namespace = ovh.CloudProject.get_m3db_namespace(service_name="XXX",
        cluster_id="YYY",
        name="ZZZ")
    pulumi.export("m3dbnamespaceType", m3db_namespace.type)
    ```


    :param builtins.str cluster_id: Cluster ID
    :param builtins.str name: Name of the namespace.
    :param builtins.str service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    """
    __args__ = dict()
    __args__['clusterId'] = cluster_id
    __args__['name'] = name
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:CloudProject/getM3dbNamespace:getM3dbNamespace', __args__, opts=opts, typ=GetM3dbNamespaceResult)
    return __ret__.apply(lambda __response__: GetM3dbNamespaceResult(
        cluster_id=pulumi.get(__response__, 'cluster_id'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        resolution=pulumi.get(__response__, 'resolution'),
        retention_block_data_expiration_duration=pulumi.get(__response__, 'retention_block_data_expiration_duration'),
        retention_block_size_duration=pulumi.get(__response__, 'retention_block_size_duration'),
        retention_buffer_future_duration=pulumi.get(__response__, 'retention_buffer_future_duration'),
        retention_buffer_past_duration=pulumi.get(__response__, 'retention_buffer_past_duration'),
        retention_period_duration=pulumi.get(__response__, 'retention_period_duration'),
        service_name=pulumi.get(__response__, 'service_name'),
        snapshot_enabled=pulumi.get(__response__, 'snapshot_enabled'),
        type=pulumi.get(__response__, 'type'),
        writes_to_commit_log_enabled=pulumi.get(__response__, 'writes_to_commit_log_enabled')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['PolicyArgs', 'Policy']

@pulumi.input_type
class PolicyArgs:
    def __init__(__self__, *,
                 identities: pulumi.Input[Sequence[pulumi.Input[builtins.str]]],
                 resources: pulumi.Input[Sequence[pulumi.Input[builtins.str]]],
                 allows: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 denies: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 excepts: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 permissions_groups: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        The set of arguments for constructing a Policy resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] identities: List of identities affected by the policy
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] resources: List of resources affected by the policy
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] allows: List of actions allowed on resources by identities
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] denies: List of actions that will always be denied even if also allowed by this policy or another one.
        :param pulumi.Input[builtins.str] description: Description of the policy
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] excepts: List of overrides of action that must not be allowed even if they are caught by allow. Only makes sens if allow contains wildcards.
        :param pulumi.Input[builtins.str] name: Name of the policy, must be unique
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] permissions_groups: Set of permissions groups included in the policy. At evaluation, these permissions groups are each evaluated independently (notably, excepts actions only affect actions in the same permission group).
        """
        pulumi.set(__self__, "identities", identities)
        pulumi.set(__self__, "resources", resources)
        if allows is not None:
            pulumi.set(__self__, "allows", allows)
        if denies is not None:
            pulumi.set(__self__, "denies", denies)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if excepts is not None:
            pulumi.set(__self__, "excepts", excepts)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if permissions_groups is not None:
            pulumi.set(__self__, "permissions_groups", permissions_groups)

    @property
    @pulumi.getter
    def identities(self) -> pulumi.Input[Sequence[pulumi.Input[builtins.str]]]:
        """
        List of identities affected by the policy
        """
        return pulumi.get(self, "identities")

    @identities.setter
    def identities(self, value: pulumi.Input[Sequence[pulumi.Input[builtins.str]]]):
        pulumi.set(self, "identities", value)

    @property
    @pulumi.getter
    def resources(self) -> pulumi.Input[Sequence[pulumi.Input[builtins.str]]]:
        """
        List of resources affected by the policy
        """
        return pulumi.get(self, "resources")

    @resources.setter
    def resources(self, value: pulumi.Input[Sequence[pulumi.Input[builtins.str]]]):
        pulumi.set(self, "resources", value)

    @property
    @pulumi.getter
    def allows(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of actions allowed on resources by identities
        """
        return pulumi.get(self, "allows")

    @allows.setter
    def allows(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "allows", value)

    @property
    @pulumi.getter
    def denies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of actions that will always be denied even if also allowed by this policy or another one.
        """
        return pulumi.get(self, "denies")

    @denies.setter
    def denies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "denies", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Description of the policy
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def excepts(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of overrides of action that must not be allowed even if they are caught by allow. Only makes sens if allow contains wildcards.
        """
        return pulumi.get(self, "excepts")

    @excepts.setter
    def excepts(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "excepts", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Name of the policy, must be unique
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="permissionsGroups")
    def permissions_groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Set of permissions groups included in the policy. At evaluation, these permissions groups are each evaluated independently (notably, excepts actions only affect actions in the same permission group).
        """
        return pulumi.get(self, "permissions_groups")

    @permissions_groups.setter
    def permissions_groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "permissions_groups", value)


@pulumi.input_type
class _PolicyState:
    def __init__(__self__, *,
                 allows: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 created_at: Optional[pulumi.Input[builtins.str]] = None,
                 denies: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 excepts: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 identities: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 owner: Optional[pulumi.Input[builtins.str]] = None,
                 permissions_groups: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 read_only: Optional[pulumi.Input[builtins.bool]] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 updated_at: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Policy resources.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] allows: List of actions allowed on resources by identities
        :param pulumi.Input[builtins.str] created_at: Creation date of this group.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] denies: List of actions that will always be denied even if also allowed by this policy or another one.
        :param pulumi.Input[builtins.str] description: Description of the policy
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] excepts: List of overrides of action that must not be allowed even if they are caught by allow. Only makes sens if allow contains wildcards.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] identities: List of identities affected by the policy
        :param pulumi.Input[builtins.str] name: Name of the policy, must be unique
        :param pulumi.Input[builtins.str] owner: Owner of the policy.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] permissions_groups: Set of permissions groups included in the policy. At evaluation, these permissions groups are each evaluated independently (notably, excepts actions only affect actions in the same permission group).
        :param pulumi.Input[builtins.bool] read_only: Indicates that the policy is a default one.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] resources: List of resources affected by the policy
        :param pulumi.Input[builtins.str] updated_at: Date of the last update of this group.
        """
        if allows is not None:
            pulumi.set(__self__, "allows", allows)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if denies is not None:
            pulumi.set(__self__, "denies", denies)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if excepts is not None:
            pulumi.set(__self__, "excepts", excepts)
        if identities is not None:
            pulumi.set(__self__, "identities", identities)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if permissions_groups is not None:
            pulumi.set(__self__, "permissions_groups", permissions_groups)
        if read_only is not None:
            pulumi.set(__self__, "read_only", read_only)
        if resources is not None:
            pulumi.set(__self__, "resources", resources)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter
    def allows(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of actions allowed on resources by identities
        """
        return pulumi.get(self, "allows")

    @allows.setter
    def allows(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "allows", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Creation date of this group.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def denies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of actions that will always be denied even if also allowed by this policy or another one.
        """
        return pulumi.get(self, "denies")

    @denies.setter
    def denies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "denies", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Description of the policy
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def excepts(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of overrides of action that must not be allowed even if they are caught by allow. Only makes sens if allow contains wildcards.
        """
        return pulumi.get(self, "excepts")

    @excepts.setter
    def excepts(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "excepts", value)

    @property
    @pulumi.getter
    def identities(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of identities affected by the policy
        """
        return pulumi.get(self, "identities")

    @identities.setter
    def identities(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "identities", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Name of the policy, must be unique
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Owner of the policy.
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "owner", value)

    @property
    @pulumi.getter(name="permissionsGroups")
    def permissions_groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Set of permissions groups included in the policy. At evaluation, these permissions groups are each evaluated independently (notably, excepts actions only affect actions in the same permission group).
        """
        return pulumi.get(self, "permissions_groups")

    @permissions_groups.setter
    def permissions_groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "permissions_groups", value)

    @property
    @pulumi.getter(name="readOnly")
    def read_only(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Indicates that the policy is a default one.
        """
        return pulumi.get(self, "read_only")

    @read_only.setter
    def read_only(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "read_only", value)

    @property
    @pulumi.getter
    def resources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of resources affected by the policy
        """
        return pulumi.get(self, "resources")

    @resources.setter
    def resources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "resources", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Date of the last update of this group.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_at", value)


@pulumi.type_token("ovh:Iam/policy:Policy")
class Policy(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allows: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 denies: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 excepts: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 identities: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 permissions_groups: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        """
        Creates an IAM policy.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        account = ovh.Me.get_me()
        my_group = ovh.me.IdentityGroup("my_group",
            name="my_group",
            description="my_group created in Terraform")
        manager = ovh.iam.Policy("manager",
            name="allow_ovh_manager",
            description="Users are allowed to use the OVH manager",
            identities=[my_group.group_urn],
            resources=[account.account_urn],
            allows=[
                "account:apiovh:me/get",
                "account:apiovh:me/supportLevel/get",
                "account:apiovh:me/certificates/get",
                "account:apiovh:me/tag/get",
                "account:apiovh:services/get",
                "account:apiovh:*",
            ])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] allows: List of actions allowed on resources by identities
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] denies: List of actions that will always be denied even if also allowed by this policy or another one.
        :param pulumi.Input[builtins.str] description: Description of the policy
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] excepts: List of overrides of action that must not be allowed even if they are caught by allow. Only makes sens if allow contains wildcards.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] identities: List of identities affected by the policy
        :param pulumi.Input[builtins.str] name: Name of the policy, must be unique
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] permissions_groups: Set of permissions groups included in the policy. At evaluation, these permissions groups are each evaluated independently (notably, excepts actions only affect actions in the same permission group).
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] resources: List of resources affected by the policy
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PolicyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates an IAM policy.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        account = ovh.Me.get_me()
        my_group = ovh.me.IdentityGroup("my_group",
            name="my_group",
            description="my_group created in Terraform")
        manager = ovh.iam.Policy("manager",
            name="allow_ovh_manager",
            description="Users are allowed to use the OVH manager",
            identities=[my_group.group_urn],
            resources=[account.account_urn],
            allows=[
                "account:apiovh:me/get",
                "account:apiovh:me/supportLevel/get",
                "account:apiovh:me/certificates/get",
                "account:apiovh:me/tag/get",
                "account:apiovh:services/get",
                "account:apiovh:*",
            ])
        ```

        :param str resource_name: The name of the resource.
        :param PolicyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PolicyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allows: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 denies: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 excepts: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 identities: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 permissions_groups: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PolicyArgs.__new__(PolicyArgs)

            __props__.__dict__["allows"] = allows
            __props__.__dict__["denies"] = denies
            __props__.__dict__["description"] = description
            __props__.__dict__["excepts"] = excepts
            if identities is None and not opts.urn:
                raise TypeError("Missing required property 'identities'")
            __props__.__dict__["identities"] = identities
            __props__.__dict__["name"] = name
            __props__.__dict__["permissions_groups"] = permissions_groups
            if resources is None and not opts.urn:
                raise TypeError("Missing required property 'resources'")
            __props__.__dict__["resources"] = resources
            __props__.__dict__["created_at"] = None
            __props__.__dict__["owner"] = None
            __props__.__dict__["read_only"] = None
            __props__.__dict__["updated_at"] = None
        super(Policy, __self__).__init__(
            'ovh:Iam/policy:Policy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            allows: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            created_at: Optional[pulumi.Input[builtins.str]] = None,
            denies: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            excepts: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            identities: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            owner: Optional[pulumi.Input[builtins.str]] = None,
            permissions_groups: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            read_only: Optional[pulumi.Input[builtins.bool]] = None,
            resources: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            updated_at: Optional[pulumi.Input[builtins.str]] = None) -> 'Policy':
        """
        Get an existing Policy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] allows: List of actions allowed on resources by identities
        :param pulumi.Input[builtins.str] created_at: Creation date of this group.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] denies: List of actions that will always be denied even if also allowed by this policy or another one.
        :param pulumi.Input[builtins.str] description: Description of the policy
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] excepts: List of overrides of action that must not be allowed even if they are caught by allow. Only makes sens if allow contains wildcards.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] identities: List of identities affected by the policy
        :param pulumi.Input[builtins.str] name: Name of the policy, must be unique
        :param pulumi.Input[builtins.str] owner: Owner of the policy.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] permissions_groups: Set of permissions groups included in the policy. At evaluation, these permissions groups are each evaluated independently (notably, excepts actions only affect actions in the same permission group).
        :param pulumi.Input[builtins.bool] read_only: Indicates that the policy is a default one.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] resources: List of resources affected by the policy
        :param pulumi.Input[builtins.str] updated_at: Date of the last update of this group.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PolicyState.__new__(_PolicyState)

        __props__.__dict__["allows"] = allows
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["denies"] = denies
        __props__.__dict__["description"] = description
        __props__.__dict__["excepts"] = excepts
        __props__.__dict__["identities"] = identities
        __props__.__dict__["name"] = name
        __props__.__dict__["owner"] = owner
        __props__.__dict__["permissions_groups"] = permissions_groups
        __props__.__dict__["read_only"] = read_only
        __props__.__dict__["resources"] = resources
        __props__.__dict__["updated_at"] = updated_at
        return Policy(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def allows(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        List of actions allowed on resources by identities
        """
        return pulumi.get(self, "allows")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[builtins.str]:
        """
        Creation date of this group.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def denies(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        List of actions that will always be denied even if also allowed by this policy or another one.
        """
        return pulumi.get(self, "denies")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Description of the policy
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def excepts(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        List of overrides of action that must not be allowed even if they are caught by allow. Only makes sens if allow contains wildcards.
        """
        return pulumi.get(self, "excepts")

    @property
    @pulumi.getter
    def identities(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        List of identities affected by the policy
        """
        return pulumi.get(self, "identities")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        Name of the policy, must be unique
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def owner(self) -> pulumi.Output[builtins.str]:
        """
        Owner of the policy.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter(name="permissionsGroups")
    def permissions_groups(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        Set of permissions groups included in the policy. At evaluation, these permissions groups are each evaluated independently (notably, excepts actions only affect actions in the same permission group).
        """
        return pulumi.get(self, "permissions_groups")

    @property
    @pulumi.getter(name="readOnly")
    def read_only(self) -> pulumi.Output[builtins.bool]:
        """
        Indicates that the policy is a default one.
        """
        return pulumi.get(self, "read_only")

    @property
    @pulumi.getter
    def resources(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        List of resources affected by the policy
        """
        return pulumi.get(self, "resources")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[builtins.str]:
        """
        Date of the last update of this group.
        """
        return pulumi.get(self, "updated_at")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetRegionResult',
    'AwaitableGetRegionResult',
    'get_region',
    'get_region_output',
]

@pulumi.output_type
class GetRegionResult:
    """
    A collection of values returned by getRegion.
    """
    def __init__(__self__, availability_zones=None, continent_code=None, country_code=None, datacenter_location=None, id=None, ip_countries=None, name=None, service_name=None, services=None, status=None, type=None):
        if availability_zones and not isinstance(availability_zones, list):
            raise TypeError("Expected argument 'availability_zones' to be a list")
        pulumi.set(__self__, "availability_zones", availability_zones)
        if continent_code and not isinstance(continent_code, str):
            raise TypeError("Expected argument 'continent_code' to be a str")
        pulumi.set(__self__, "continent_code", continent_code)
        if country_code and not isinstance(country_code, str):
            raise TypeError("Expected argument 'country_code' to be a str")
        pulumi.set(__self__, "country_code", country_code)
        if datacenter_location and not isinstance(datacenter_location, str):
            raise TypeError("Expected argument 'datacenter_location' to be a str")
        pulumi.set(__self__, "datacenter_location", datacenter_location)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ip_countries and not isinstance(ip_countries, list):
            raise TypeError("Expected argument 'ip_countries' to be a list")
        pulumi.set(__self__, "ip_countries", ip_countries)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if services and not isinstance(services, list):
            raise TypeError("Expected argument 'services' to be a list")
        pulumi.set(__self__, "services", services)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="availabilityZones")
    def availability_zones(self) -> Sequence[builtins.str]:
        """
        Availability zones of the region
        """
        return pulumi.get(self, "availability_zones")

    @property
    @pulumi.getter(name="continentCode")
    def continent_code(self) -> builtins.str:
        """
        The code of the geographic continent the region is running. E.g.: EU for Europe, US for America...
        """
        return pulumi.get(self, "continent_code")

    @property
    @pulumi.getter(name="countryCode")
    def country_code(self) -> builtins.str:
        """
        Region country code
        """
        return pulumi.get(self, "country_code")

    @property
    @pulumi.getter(name="datacenterLocation")
    def datacenter_location(self) -> builtins.str:
        """
        The location code of the datacenter. E.g.: "GRA", meaning Gravelines, for region "GRA1"
        """
        return pulumi.get(self, "datacenter_location")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="ipCountries")
    def ip_countries(self) -> Sequence[builtins.str]:
        """
        Allowed countries for failover IP
        """
        return pulumi.get(self, "ip_countries")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        the name of the public cloud service
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def services(self) -> Sequence['outputs.GetRegionServiceResult']:
        """
        The list of public cloud services running within the region
        """
        return pulumi.get(self, "services")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        the status of the service
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        Region type (localzone | region | region-3-az)
        """
        return pulumi.get(self, "type")


class AwaitableGetRegionResult(GetRegionResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRegionResult(
            availability_zones=self.availability_zones,
            continent_code=self.continent_code,
            country_code=self.country_code,
            datacenter_location=self.datacenter_location,
            id=self.id,
            ip_countries=self.ip_countries,
            name=self.name,
            service_name=self.service_name,
            services=self.services,
            status=self.status,
            type=self.type)


def get_region(name: Optional[builtins.str] = None,
               service_name: Optional[builtins.str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRegionResult:
    """
    Use this data source to retrieve information about a region associated with a public cloud project. The region must be associated with the project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    gra1 = ovh.CloudProject.get_region(service_name="XXXXXX",
        name="GRA1")
    ```


    :param builtins.str name: The name of the region associated with the public cloud project.
    :param builtins.str service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:CloudProject/getRegion:getRegion', __args__, opts=opts, typ=GetRegionResult).value

    return AwaitableGetRegionResult(
        availability_zones=pulumi.get(__ret__, 'availability_zones'),
        continent_code=pulumi.get(__ret__, 'continent_code'),
        country_code=pulumi.get(__ret__, 'country_code'),
        datacenter_location=pulumi.get(__ret__, 'datacenter_location'),
        id=pulumi.get(__ret__, 'id'),
        ip_countries=pulumi.get(__ret__, 'ip_countries'),
        name=pulumi.get(__ret__, 'name'),
        service_name=pulumi.get(__ret__, 'service_name'),
        services=pulumi.get(__ret__, 'services'),
        status=pulumi.get(__ret__, 'status'),
        type=pulumi.get(__ret__, 'type'))
def get_region_output(name: Optional[pulumi.Input[builtins.str]] = None,
                      service_name: Optional[pulumi.Input[builtins.str]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRegionResult]:
    """
    Use this data source to retrieve information about a region associated with a public cloud project. The region must be associated with the project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    gra1 = ovh.CloudProject.get_region(service_name="XXXXXX",
        name="GRA1")
    ```


    :param builtins.str name: The name of the region associated with the public cloud project.
    :param builtins.str service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:CloudProject/getRegion:getRegion', __args__, opts=opts, typ=GetRegionResult)
    return __ret__.apply(lambda __response__: GetRegionResult(
        availability_zones=pulumi.get(__response__, 'availability_zones'),
        continent_code=pulumi.get(__response__, 'continent_code'),
        country_code=pulumi.get(__response__, 'country_code'),
        datacenter_location=pulumi.get(__response__, 'datacenter_location'),
        id=pulumi.get(__response__, 'id'),
        ip_countries=pulumi.get(__response__, 'ip_countries'),
        name=pulumi.get(__response__, 'name'),
        service_name=pulumi.get(__response__, 'service_name'),
        services=pulumi.get(__response__, 'services'),
        status=pulumi.get(__response__, 'status'),
        type=pulumi.get(__response__, 'type')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['PrivateDatabaseArgs', 'PrivateDatabase']

@pulumi.input_type
class PrivateDatabaseArgs:
    def __init__(__self__, *,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 orders: Optional[pulumi.Input[Sequence[pulumi.Input['PrivateDatabaseOrderArgs']]]] = None,
                 ovh_subsidiary: Optional[pulumi.Input[builtins.str]] = None,
                 payment_mean: Optional[pulumi.Input[builtins.str]] = None,
                 plan: Optional[pulumi.Input['PrivateDatabasePlanArgs']] = None,
                 plan_options: Optional[pulumi.Input[Sequence[pulumi.Input['PrivateDatabasePlanOptionArgs']]]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a PrivateDatabase resource.
        :param pulumi.Input[builtins.str] display_name: Name displayed in customer panel for your private database
        :param pulumi.Input[Sequence[pulumi.Input['PrivateDatabaseOrderArgs']]] orders: Details about your Order
        :param pulumi.Input[builtins.str] ovh_subsidiary: OVHcloud Subsidiary. Country of OVHcloud legal entity you'll be billed by. List of supported subsidiaries available on API at [/1.0/me.json under `models.nichandle.OvhSubsidiaryEnum`](https://eu.api.ovh.com/1.0/me.json)
        :param pulumi.Input[builtins.str] payment_mean: Ovh payment mode
        :param pulumi.Input['PrivateDatabasePlanArgs'] plan: Product Plan to order
        :param pulumi.Input[Sequence[pulumi.Input['PrivateDatabasePlanOptionArgs']]] plan_options: Product Plan to order
        :param pulumi.Input[builtins.str] service_name: Service name
        """
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if orders is not None:
            pulumi.set(__self__, "orders", orders)
        if ovh_subsidiary is not None:
            pulumi.set(__self__, "ovh_subsidiary", ovh_subsidiary)
        if payment_mean is not None:
            warnings.warn("""This field is not anymore used since the API has been deprecated in favor of /payment/mean. Now, the default payment mean is used.""", DeprecationWarning)
            pulumi.log.warn("""payment_mean is deprecated: This field is not anymore used since the API has been deprecated in favor of /payment/mean. Now, the default payment mean is used.""")
        if payment_mean is not None:
            pulumi.set(__self__, "payment_mean", payment_mean)
        if plan is not None:
            pulumi.set(__self__, "plan", plan)
        if plan_options is not None:
            pulumi.set(__self__, "plan_options", plan_options)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Name displayed in customer panel for your private database
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter
    def orders(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PrivateDatabaseOrderArgs']]]]:
        """
        Details about your Order
        """
        return pulumi.get(self, "orders")

    @orders.setter
    def orders(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PrivateDatabaseOrderArgs']]]]):
        pulumi.set(self, "orders", value)

    @property
    @pulumi.getter(name="ovhSubsidiary")
    def ovh_subsidiary(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        OVHcloud Subsidiary. Country of OVHcloud legal entity you'll be billed by. List of supported subsidiaries available on API at [/1.0/me.json under `models.nichandle.OvhSubsidiaryEnum`](https://eu.api.ovh.com/1.0/me.json)
        """
        return pulumi.get(self, "ovh_subsidiary")

    @ovh_subsidiary.setter
    def ovh_subsidiary(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ovh_subsidiary", value)

    @property
    @pulumi.getter(name="paymentMean")
    @_utilities.deprecated("""This field is not anymore used since the API has been deprecated in favor of /payment/mean. Now, the default payment mean is used.""")
    def payment_mean(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Ovh payment mode
        """
        return pulumi.get(self, "payment_mean")

    @payment_mean.setter
    def payment_mean(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "payment_mean", value)

    @property
    @pulumi.getter
    def plan(self) -> Optional[pulumi.Input['PrivateDatabasePlanArgs']]:
        """
        Product Plan to order
        """
        return pulumi.get(self, "plan")

    @plan.setter
    def plan(self, value: Optional[pulumi.Input['PrivateDatabasePlanArgs']]):
        pulumi.set(self, "plan", value)

    @property
    @pulumi.getter(name="planOptions")
    def plan_options(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PrivateDatabasePlanOptionArgs']]]]:
        """
        Product Plan to order
        """
        return pulumi.get(self, "plan_options")

    @plan_options.setter
    def plan_options(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PrivateDatabasePlanOptionArgs']]]]):
        pulumi.set(self, "plan_options", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Service name
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)


@pulumi.input_type
class _PrivateDatabaseState:
    def __init__(__self__, *,
                 database_urn: Optional[pulumi.Input[builtins.str]] = None,
                 cpu: Optional[pulumi.Input[builtins.int]] = None,
                 datacenter: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 hostname: Optional[pulumi.Input[builtins.str]] = None,
                 hostname_ftp: Optional[pulumi.Input[builtins.str]] = None,
                 infrastructure: Optional[pulumi.Input[builtins.str]] = None,
                 offer: Optional[pulumi.Input[builtins.str]] = None,
                 orders: Optional[pulumi.Input[Sequence[pulumi.Input['PrivateDatabaseOrderArgs']]]] = None,
                 ovh_subsidiary: Optional[pulumi.Input[builtins.str]] = None,
                 payment_mean: Optional[pulumi.Input[builtins.str]] = None,
                 plan: Optional[pulumi.Input['PrivateDatabasePlanArgs']] = None,
                 plan_options: Optional[pulumi.Input[Sequence[pulumi.Input['PrivateDatabasePlanOptionArgs']]]] = None,
                 port: Optional[pulumi.Input[builtins.int]] = None,
                 port_ftp: Optional[pulumi.Input[builtins.int]] = None,
                 quota_size: Optional[pulumi.Input[builtins.int]] = None,
                 quota_used: Optional[pulumi.Input[builtins.int]] = None,
                 ram: Optional[pulumi.Input[builtins.int]] = None,
                 server: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 state: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 version: Optional[pulumi.Input[builtins.str]] = None,
                 version_label: Optional[pulumi.Input[builtins.str]] = None,
                 version_number: Optional[pulumi.Input[builtins.float]] = None):
        """
        Input properties used for looking up and filtering PrivateDatabase resources.
        :param pulumi.Input[builtins.str] database_urn: URN of the private database, used when writing IAM policies
        :param pulumi.Input[builtins.int] cpu: Number of CPU on your private database
        :param pulumi.Input[builtins.str] datacenter: Datacenter where this private database is located
        :param pulumi.Input[builtins.str] display_name: Name displayed in customer panel for your private database
        :param pulumi.Input[builtins.str] hostname: Private database hostname
        :param pulumi.Input[builtins.str] hostname_ftp: Private database FTP hostname
        :param pulumi.Input[builtins.str] infrastructure: Infrastructure where service was stored
        :param pulumi.Input[builtins.str] offer: Type of the private database offer
        :param pulumi.Input[Sequence[pulumi.Input['PrivateDatabaseOrderArgs']]] orders: Details about your Order
        :param pulumi.Input[builtins.str] ovh_subsidiary: OVHcloud Subsidiary. Country of OVHcloud legal entity you'll be billed by. List of supported subsidiaries available on API at [/1.0/me.json under `models.nichandle.OvhSubsidiaryEnum`](https://eu.api.ovh.com/1.0/me.json)
        :param pulumi.Input[builtins.str] payment_mean: Ovh payment mode
        :param pulumi.Input['PrivateDatabasePlanArgs'] plan: Product Plan to order
        :param pulumi.Input[Sequence[pulumi.Input['PrivateDatabasePlanOptionArgs']]] plan_options: Product Plan to order
        :param pulumi.Input[builtins.int] port: Private database service port
        :param pulumi.Input[builtins.int] port_ftp: Private database FTP port
        :param pulumi.Input[builtins.int] quota_size: Space allowed (in MB) on your private database
        :param pulumi.Input[builtins.int] quota_used: Sapce used (in MB) on your private database
        :param pulumi.Input[builtins.int] ram: Amount of ram (in MB) on your private database
        :param pulumi.Input[builtins.str] server: Private database server name
        :param pulumi.Input[builtins.str] service_name: Service name
        :param pulumi.Input[builtins.str] state: Private database state
        :param pulumi.Input[builtins.str] type: Private database type
        :param pulumi.Input[builtins.str] version: Private database available versions
        :param pulumi.Input[builtins.str] version_label: Private database version label
        :param pulumi.Input[builtins.float] version_number: Private database version number
        """
        if database_urn is not None:
            pulumi.set(__self__, "database_urn", database_urn)
        if cpu is not None:
            pulumi.set(__self__, "cpu", cpu)
        if datacenter is not None:
            pulumi.set(__self__, "datacenter", datacenter)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if hostname is not None:
            pulumi.set(__self__, "hostname", hostname)
        if hostname_ftp is not None:
            pulumi.set(__self__, "hostname_ftp", hostname_ftp)
        if infrastructure is not None:
            pulumi.set(__self__, "infrastructure", infrastructure)
        if offer is not None:
            pulumi.set(__self__, "offer", offer)
        if orders is not None:
            pulumi.set(__self__, "orders", orders)
        if ovh_subsidiary is not None:
            pulumi.set(__self__, "ovh_subsidiary", ovh_subsidiary)
        if payment_mean is not None:
            warnings.warn("""This field is not anymore used since the API has been deprecated in favor of /payment/mean. Now, the default payment mean is used.""", DeprecationWarning)
            pulumi.log.warn("""payment_mean is deprecated: This field is not anymore used since the API has been deprecated in favor of /payment/mean. Now, the default payment mean is used.""")
        if payment_mean is not None:
            pulumi.set(__self__, "payment_mean", payment_mean)
        if plan is not None:
            pulumi.set(__self__, "plan", plan)
        if plan_options is not None:
            pulumi.set(__self__, "plan_options", plan_options)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if port_ftp is not None:
            pulumi.set(__self__, "port_ftp", port_ftp)
        if quota_size is not None:
            pulumi.set(__self__, "quota_size", quota_size)
        if quota_used is not None:
            pulumi.set(__self__, "quota_used", quota_used)
        if ram is not None:
            pulumi.set(__self__, "ram", ram)
        if server is not None:
            pulumi.set(__self__, "server", server)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if version is not None:
            pulumi.set(__self__, "version", version)
        if version_label is not None:
            pulumi.set(__self__, "version_label", version_label)
        if version_number is not None:
            pulumi.set(__self__, "version_number", version_number)

    @property
    @pulumi.getter(name="DatabaseURN")
    def database_urn(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        URN of the private database, used when writing IAM policies
        """
        return pulumi.get(self, "database_urn")

    @database_urn.setter
    def database_urn(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "database_urn", value)

    @property
    @pulumi.getter
    def cpu(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Number of CPU on your private database
        """
        return pulumi.get(self, "cpu")

    @cpu.setter
    def cpu(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "cpu", value)

    @property
    @pulumi.getter
    def datacenter(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Datacenter where this private database is located
        """
        return pulumi.get(self, "datacenter")

    @datacenter.setter
    def datacenter(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "datacenter", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Name displayed in customer panel for your private database
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter
    def hostname(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Private database hostname
        """
        return pulumi.get(self, "hostname")

    @hostname.setter
    def hostname(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "hostname", value)

    @property
    @pulumi.getter(name="hostnameFtp")
    def hostname_ftp(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Private database FTP hostname
        """
        return pulumi.get(self, "hostname_ftp")

    @hostname_ftp.setter
    def hostname_ftp(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "hostname_ftp", value)

    @property
    @pulumi.getter
    def infrastructure(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Infrastructure where service was stored
        """
        return pulumi.get(self, "infrastructure")

    @infrastructure.setter
    def infrastructure(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "infrastructure", value)

    @property
    @pulumi.getter
    def offer(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Type of the private database offer
        """
        return pulumi.get(self, "offer")

    @offer.setter
    def offer(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "offer", value)

    @property
    @pulumi.getter
    def orders(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PrivateDatabaseOrderArgs']]]]:
        """
        Details about your Order
        """
        return pulumi.get(self, "orders")

    @orders.setter
    def orders(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PrivateDatabaseOrderArgs']]]]):
        pulumi.set(self, "orders", value)

    @property
    @pulumi.getter(name="ovhSubsidiary")
    def ovh_subsidiary(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        OVHcloud Subsidiary. Country of OVHcloud legal entity you'll be billed by. List of supported subsidiaries available on API at [/1.0/me.json under `models.nichandle.OvhSubsidiaryEnum`](https://eu.api.ovh.com/1.0/me.json)
        """
        return pulumi.get(self, "ovh_subsidiary")

    @ovh_subsidiary.setter
    def ovh_subsidiary(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ovh_subsidiary", value)

    @property
    @pulumi.getter(name="paymentMean")
    @_utilities.deprecated("""This field is not anymore used since the API has been deprecated in favor of /payment/mean. Now, the default payment mean is used.""")
    def payment_mean(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Ovh payment mode
        """
        return pulumi.get(self, "payment_mean")

    @payment_mean.setter
    def payment_mean(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "payment_mean", value)

    @property
    @pulumi.getter
    def plan(self) -> Optional[pulumi.Input['PrivateDatabasePlanArgs']]:
        """
        Product Plan to order
        """
        return pulumi.get(self, "plan")

    @plan.setter
    def plan(self, value: Optional[pulumi.Input['PrivateDatabasePlanArgs']]):
        pulumi.set(self, "plan", value)

    @property
    @pulumi.getter(name="planOptions")
    def plan_options(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PrivateDatabasePlanOptionArgs']]]]:
        """
        Product Plan to order
        """
        return pulumi.get(self, "plan_options")

    @plan_options.setter
    def plan_options(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PrivateDatabasePlanOptionArgs']]]]):
        pulumi.set(self, "plan_options", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Private database service port
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter(name="portFtp")
    def port_ftp(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Private database FTP port
        """
        return pulumi.get(self, "port_ftp")

    @port_ftp.setter
    def port_ftp(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "port_ftp", value)

    @property
    @pulumi.getter(name="quotaSize")
    def quota_size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Space allowed (in MB) on your private database
        """
        return pulumi.get(self, "quota_size")

    @quota_size.setter
    def quota_size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "quota_size", value)

    @property
    @pulumi.getter(name="quotaUsed")
    def quota_used(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Sapce used (in MB) on your private database
        """
        return pulumi.get(self, "quota_used")

    @quota_used.setter
    def quota_used(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "quota_used", value)

    @property
    @pulumi.getter
    def ram(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Amount of ram (in MB) on your private database
        """
        return pulumi.get(self, "ram")

    @ram.setter
    def ram(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "ram", value)

    @property
    @pulumi.getter
    def server(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Private database server name
        """
        return pulumi.get(self, "server")

    @server.setter
    def server(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "server", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Service name
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Private database state
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Private database type
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Private database available versions
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "version", value)

    @property
    @pulumi.getter(name="versionLabel")
    def version_label(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Private database version label
        """
        return pulumi.get(self, "version_label")

    @version_label.setter
    def version_label(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "version_label", value)

    @property
    @pulumi.getter(name="versionNumber")
    def version_number(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        Private database version number
        """
        return pulumi.get(self, "version_number")

    @version_number.setter
    def version_number(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "version_number", value)


@pulumi.type_token("ovh:Hosting/privateDatabase:PrivateDatabase")
class PrivateDatabase(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 orders: Optional[pulumi.Input[Sequence[pulumi.Input[Union['PrivateDatabaseOrderArgs', 'PrivateDatabaseOrderArgsDict']]]]] = None,
                 ovh_subsidiary: Optional[pulumi.Input[builtins.str]] = None,
                 payment_mean: Optional[pulumi.Input[builtins.str]] = None,
                 plan: Optional[pulumi.Input[Union['PrivateDatabasePlanArgs', 'PrivateDatabasePlanArgsDict']]] = None,
                 plan_options: Optional[pulumi.Input[Sequence[pulumi.Input[Union['PrivateDatabasePlanOptionArgs', 'PrivateDatabasePlanOptionArgsDict']]]]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        myaccount = ovh.Me.get_me()
        mycart = ovh.Order.get_cart(ovh_subsidiary=myaccount.ovh_subsidiary)
        database = ovh.Order.get_cart_product_plan(cart_id=mycart.id,
            price_capacity="renew",
            product="privateSQL",
            plan_code="private-sql-512-instance")
        database_private_database = ovh.hosting.PrivateDatabase("database",
            ovh_subsidiary=mycart.ovh_subsidiary,
            display_name="Postgresql-12",
            plan={
                "duration": database.prices[3].duration,
                "plan_code": database.plan_code,
                "pricing_mode": database.selected_prices[0].pricing_mode,
                "configurations": [
                    {
                        "label": "dc",
                        "value": "gra3",
                    },
                    {
                        "label": "engine",
                        "value": "postgresql_12",
                    },
                ],
            })
        pulumi.export("privatedatabaseServiceName", database_private_database.service_name)
        ```

        ## Import

        OVHcloud Webhosting database can be imported using the `service_name`. Using the following configuration:

        terraform

        import {

          to = ovh_hosting_privatedatabase.database

          id = "<service name>"

        }

        You can then run:

        bash

        $ pulumi preview -generate-config-out=database.tf

        $ pulumi up

        The file `database.tf` will then contain the imported resource's configuration, that can be copied next to the `import` block above. See https://developer.hashicorp.com/terraform/language/import/generating-configuration for more details.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] display_name: Name displayed in customer panel for your private database
        :param pulumi.Input[Sequence[pulumi.Input[Union['PrivateDatabaseOrderArgs', 'PrivateDatabaseOrderArgsDict']]]] orders: Details about your Order
        :param pulumi.Input[builtins.str] ovh_subsidiary: OVHcloud Subsidiary. Country of OVHcloud legal entity you'll be billed by. List of supported subsidiaries available on API at [/1.0/me.json under `models.nichandle.OvhSubsidiaryEnum`](https://eu.api.ovh.com/1.0/me.json)
        :param pulumi.Input[builtins.str] payment_mean: Ovh payment mode
        :param pulumi.Input[Union['PrivateDatabasePlanArgs', 'PrivateDatabasePlanArgsDict']] plan: Product Plan to order
        :param pulumi.Input[Sequence[pulumi.Input[Union['PrivateDatabasePlanOptionArgs', 'PrivateDatabasePlanOptionArgsDict']]]] plan_options: Product Plan to order
        :param pulumi.Input[builtins.str] service_name: Service name
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[PrivateDatabaseArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        myaccount = ovh.Me.get_me()
        mycart = ovh.Order.get_cart(ovh_subsidiary=myaccount.ovh_subsidiary)
        database = ovh.Order.get_cart_product_plan(cart_id=mycart.id,
            price_capacity="renew",
            product="privateSQL",
            plan_code="private-sql-512-instance")
        database_private_database = ovh.hosting.PrivateDatabase("database",
            ovh_subsidiary=mycart.ovh_subsidiary,
            display_name="Postgresql-12",
            plan={
                "duration": database.prices[3].duration,
                "plan_code": database.plan_code,
                "pricing_mode": database.selected_prices[0].pricing_mode,
                "configurations": [
                    {
                        "label": "dc",
                        "value": "gra3",
                    },
                    {
                        "label": "engine",
                        "value": "postgresql_12",
                    },
                ],
            })
        pulumi.export("privatedatabaseServiceName", database_private_database.service_name)
        ```

        ## Import

        OVHcloud Webhosting database can be imported using the `service_name`. Using the following configuration:

        terraform

        import {

          to = ovh_hosting_privatedatabase.database

          id = "<service name>"

        }

        You can then run:

        bash

        $ pulumi preview -generate-config-out=database.tf

        $ pulumi up

        The file `database.tf` will then contain the imported resource's configuration, that can be copied next to the `import` block above. See https://developer.hashicorp.com/terraform/language/import/generating-configuration for more details.

        :param str resource_name: The name of the resource.
        :param PrivateDatabaseArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PrivateDatabaseArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 orders: Optional[pulumi.Input[Sequence[pulumi.Input[Union['PrivateDatabaseOrderArgs', 'PrivateDatabaseOrderArgsDict']]]]] = None,
                 ovh_subsidiary: Optional[pulumi.Input[builtins.str]] = None,
                 payment_mean: Optional[pulumi.Input[builtins.str]] = None,
                 plan: Optional[pulumi.Input[Union['PrivateDatabasePlanArgs', 'PrivateDatabasePlanArgsDict']]] = None,
                 plan_options: Optional[pulumi.Input[Sequence[pulumi.Input[Union['PrivateDatabasePlanOptionArgs', 'PrivateDatabasePlanOptionArgsDict']]]]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PrivateDatabaseArgs.__new__(PrivateDatabaseArgs)

            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["orders"] = orders
            __props__.__dict__["ovh_subsidiary"] = ovh_subsidiary
            __props__.__dict__["payment_mean"] = payment_mean
            __props__.__dict__["plan"] = plan
            __props__.__dict__["plan_options"] = plan_options
            __props__.__dict__["service_name"] = service_name
            __props__.__dict__["database_urn"] = None
            __props__.__dict__["cpu"] = None
            __props__.__dict__["datacenter"] = None
            __props__.__dict__["hostname"] = None
            __props__.__dict__["hostname_ftp"] = None
            __props__.__dict__["infrastructure"] = None
            __props__.__dict__["offer"] = None
            __props__.__dict__["port"] = None
            __props__.__dict__["port_ftp"] = None
            __props__.__dict__["quota_size"] = None
            __props__.__dict__["quota_used"] = None
            __props__.__dict__["ram"] = None
            __props__.__dict__["server"] = None
            __props__.__dict__["state"] = None
            __props__.__dict__["type"] = None
            __props__.__dict__["version"] = None
            __props__.__dict__["version_label"] = None
            __props__.__dict__["version_number"] = None
        super(PrivateDatabase, __self__).__init__(
            'ovh:Hosting/privateDatabase:PrivateDatabase',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            database_urn: Optional[pulumi.Input[builtins.str]] = None,
            cpu: Optional[pulumi.Input[builtins.int]] = None,
            datacenter: Optional[pulumi.Input[builtins.str]] = None,
            display_name: Optional[pulumi.Input[builtins.str]] = None,
            hostname: Optional[pulumi.Input[builtins.str]] = None,
            hostname_ftp: Optional[pulumi.Input[builtins.str]] = None,
            infrastructure: Optional[pulumi.Input[builtins.str]] = None,
            offer: Optional[pulumi.Input[builtins.str]] = None,
            orders: Optional[pulumi.Input[Sequence[pulumi.Input[Union['PrivateDatabaseOrderArgs', 'PrivateDatabaseOrderArgsDict']]]]] = None,
            ovh_subsidiary: Optional[pulumi.Input[builtins.str]] = None,
            payment_mean: Optional[pulumi.Input[builtins.str]] = None,
            plan: Optional[pulumi.Input[Union['PrivateDatabasePlanArgs', 'PrivateDatabasePlanArgsDict']]] = None,
            plan_options: Optional[pulumi.Input[Sequence[pulumi.Input[Union['PrivateDatabasePlanOptionArgs', 'PrivateDatabasePlanOptionArgsDict']]]]] = None,
            port: Optional[pulumi.Input[builtins.int]] = None,
            port_ftp: Optional[pulumi.Input[builtins.int]] = None,
            quota_size: Optional[pulumi.Input[builtins.int]] = None,
            quota_used: Optional[pulumi.Input[builtins.int]] = None,
            ram: Optional[pulumi.Input[builtins.int]] = None,
            server: Optional[pulumi.Input[builtins.str]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            state: Optional[pulumi.Input[builtins.str]] = None,
            type: Optional[pulumi.Input[builtins.str]] = None,
            version: Optional[pulumi.Input[builtins.str]] = None,
            version_label: Optional[pulumi.Input[builtins.str]] = None,
            version_number: Optional[pulumi.Input[builtins.float]] = None) -> 'PrivateDatabase':
        """
        Get an existing PrivateDatabase resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] database_urn: URN of the private database, used when writing IAM policies
        :param pulumi.Input[builtins.int] cpu: Number of CPU on your private database
        :param pulumi.Input[builtins.str] datacenter: Datacenter where this private database is located
        :param pulumi.Input[builtins.str] display_name: Name displayed in customer panel for your private database
        :param pulumi.Input[builtins.str] hostname: Private database hostname
        :param pulumi.Input[builtins.str] hostname_ftp: Private database FTP hostname
        :param pulumi.Input[builtins.str] infrastructure: Infrastructure where service was stored
        :param pulumi.Input[builtins.str] offer: Type of the private database offer
        :param pulumi.Input[Sequence[pulumi.Input[Union['PrivateDatabaseOrderArgs', 'PrivateDatabaseOrderArgsDict']]]] orders: Details about your Order
        :param pulumi.Input[builtins.str] ovh_subsidiary: OVHcloud Subsidiary. Country of OVHcloud legal entity you'll be billed by. List of supported subsidiaries available on API at [/1.0/me.json under `models.nichandle.OvhSubsidiaryEnum`](https://eu.api.ovh.com/1.0/me.json)
        :param pulumi.Input[builtins.str] payment_mean: Ovh payment mode
        :param pulumi.Input[Union['PrivateDatabasePlanArgs', 'PrivateDatabasePlanArgsDict']] plan: Product Plan to order
        :param pulumi.Input[Sequence[pulumi.Input[Union['PrivateDatabasePlanOptionArgs', 'PrivateDatabasePlanOptionArgsDict']]]] plan_options: Product Plan to order
        :param pulumi.Input[builtins.int] port: Private database service port
        :param pulumi.Input[builtins.int] port_ftp: Private database FTP port
        :param pulumi.Input[builtins.int] quota_size: Space allowed (in MB) on your private database
        :param pulumi.Input[builtins.int] quota_used: Sapce used (in MB) on your private database
        :param pulumi.Input[builtins.int] ram: Amount of ram (in MB) on your private database
        :param pulumi.Input[builtins.str] server: Private database server name
        :param pulumi.Input[builtins.str] service_name: Service name
        :param pulumi.Input[builtins.str] state: Private database state
        :param pulumi.Input[builtins.str] type: Private database type
        :param pulumi.Input[builtins.str] version: Private database available versions
        :param pulumi.Input[builtins.str] version_label: Private database version label
        :param pulumi.Input[builtins.float] version_number: Private database version number
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PrivateDatabaseState.__new__(_PrivateDatabaseState)

        __props__.__dict__["database_urn"] = database_urn
        __props__.__dict__["cpu"] = cpu
        __props__.__dict__["datacenter"] = datacenter
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["hostname"] = hostname
        __props__.__dict__["hostname_ftp"] = hostname_ftp
        __props__.__dict__["infrastructure"] = infrastructure
        __props__.__dict__["offer"] = offer
        __props__.__dict__["orders"] = orders
        __props__.__dict__["ovh_subsidiary"] = ovh_subsidiary
        __props__.__dict__["payment_mean"] = payment_mean
        __props__.__dict__["plan"] = plan
        __props__.__dict__["plan_options"] = plan_options
        __props__.__dict__["port"] = port
        __props__.__dict__["port_ftp"] = port_ftp
        __props__.__dict__["quota_size"] = quota_size
        __props__.__dict__["quota_used"] = quota_used
        __props__.__dict__["ram"] = ram
        __props__.__dict__["server"] = server
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["state"] = state
        __props__.__dict__["type"] = type
        __props__.__dict__["version"] = version
        __props__.__dict__["version_label"] = version_label
        __props__.__dict__["version_number"] = version_number
        return PrivateDatabase(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="DatabaseURN")
    def database_urn(self) -> pulumi.Output[builtins.str]:
        """
        URN of the private database, used when writing IAM policies
        """
        return pulumi.get(self, "database_urn")

    @property
    @pulumi.getter
    def cpu(self) -> pulumi.Output[builtins.int]:
        """
        Number of CPU on your private database
        """
        return pulumi.get(self, "cpu")

    @property
    @pulumi.getter
    def datacenter(self) -> pulumi.Output[builtins.str]:
        """
        Datacenter where this private database is located
        """
        return pulumi.get(self, "datacenter")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[builtins.str]:
        """
        Name displayed in customer panel for your private database
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def hostname(self) -> pulumi.Output[builtins.str]:
        """
        Private database hostname
        """
        return pulumi.get(self, "hostname")

    @property
    @pulumi.getter(name="hostnameFtp")
    def hostname_ftp(self) -> pulumi.Output[builtins.str]:
        """
        Private database FTP hostname
        """
        return pulumi.get(self, "hostname_ftp")

    @property
    @pulumi.getter
    def infrastructure(self) -> pulumi.Output[builtins.str]:
        """
        Infrastructure where service was stored
        """
        return pulumi.get(self, "infrastructure")

    @property
    @pulumi.getter
    def offer(self) -> pulumi.Output[builtins.str]:
        """
        Type of the private database offer
        """
        return pulumi.get(self, "offer")

    @property
    @pulumi.getter
    def orders(self) -> pulumi.Output[Sequence['outputs.PrivateDatabaseOrder']]:
        """
        Details about your Order
        """
        return pulumi.get(self, "orders")

    @property
    @pulumi.getter(name="ovhSubsidiary")
    def ovh_subsidiary(self) -> pulumi.Output[builtins.str]:
        """
        OVHcloud Subsidiary. Country of OVHcloud legal entity you'll be billed by. List of supported subsidiaries available on API at [/1.0/me.json under `models.nichandle.OvhSubsidiaryEnum`](https://eu.api.ovh.com/1.0/me.json)
        """
        return pulumi.get(self, "ovh_subsidiary")

    @property
    @pulumi.getter(name="paymentMean")
    @_utilities.deprecated("""This field is not anymore used since the API has been deprecated in favor of /payment/mean. Now, the default payment mean is used.""")
    def payment_mean(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Ovh payment mode
        """
        return pulumi.get(self, "payment_mean")

    @property
    @pulumi.getter
    def plan(self) -> pulumi.Output['outputs.PrivateDatabasePlan']:
        """
        Product Plan to order
        """
        return pulumi.get(self, "plan")

    @property
    @pulumi.getter(name="planOptions")
    def plan_options(self) -> pulumi.Output[Optional[Sequence['outputs.PrivateDatabasePlanOption']]]:
        """
        Product Plan to order
        """
        return pulumi.get(self, "plan_options")

    @property
    @pulumi.getter
    def port(self) -> pulumi.Output[builtins.int]:
        """
        Private database service port
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter(name="portFtp")
    def port_ftp(self) -> pulumi.Output[builtins.int]:
        """
        Private database FTP port
        """
        return pulumi.get(self, "port_ftp")

    @property
    @pulumi.getter(name="quotaSize")
    def quota_size(self) -> pulumi.Output[builtins.int]:
        """
        Space allowed (in MB) on your private database
        """
        return pulumi.get(self, "quota_size")

    @property
    @pulumi.getter(name="quotaUsed")
    def quota_used(self) -> pulumi.Output[builtins.int]:
        """
        Sapce used (in MB) on your private database
        """
        return pulumi.get(self, "quota_used")

    @property
    @pulumi.getter
    def ram(self) -> pulumi.Output[builtins.int]:
        """
        Amount of ram (in MB) on your private database
        """
        return pulumi.get(self, "ram")

    @property
    @pulumi.getter
    def server(self) -> pulumi.Output[builtins.str]:
        """
        Private database server name
        """
        return pulumi.get(self, "server")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        Service name
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[builtins.str]:
        """
        Private database state
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[builtins.str]:
        """
        Private database type
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def version(self) -> pulumi.Output[builtins.str]:
        """
        Private database available versions
        """
        return pulumi.get(self, "version")

    @property
    @pulumi.getter(name="versionLabel")
    def version_label(self) -> pulumi.Output[builtins.str]:
        """
        Private database version label
        """
        return pulumi.get(self, "version_label")

    @property
    @pulumi.getter(name="versionNumber")
    def version_number(self) -> pulumi.Output[builtins.float]:
        """
        Private database version number
        """
        return pulumi.get(self, "version_number")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['LogSubscriptionArgs', 'LogSubscription']

@pulumi.input_type
class LogSubscriptionArgs:
    def __init__(__self__, *,
                 cluster_id: pulumi.Input[builtins.str],
                 engine: pulumi.Input[builtins.str],
                 kind: pulumi.Input[builtins.str],
                 stream_id: pulumi.Input[builtins.str],
                 service_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a LogSubscription resource.
        :param pulumi.Input[builtins.str] cluster_id: Cluster ID.
        :param pulumi.Input[builtins.str] engine: The database engine for which you want to manage a subscription. To get a full list of available engine visit. [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases).
        :param pulumi.Input[builtins.str] kind: Log kind name of this subscription.
        :param pulumi.Input[builtins.str] stream_id: Id of the target Log data platform stream.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        pulumi.set(__self__, "cluster_id", cluster_id)
        pulumi.set(__self__, "engine", engine)
        pulumi.set(__self__, "kind", kind)
        pulumi.set(__self__, "stream_id", stream_id)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Input[builtins.str]:
        """
        Cluster ID.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter
    def engine(self) -> pulumi.Input[builtins.str]:
        """
        The database engine for which you want to manage a subscription. To get a full list of available engine visit. [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases).
        """
        return pulumi.get(self, "engine")

    @engine.setter
    def engine(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "engine", value)

    @property
    @pulumi.getter
    def kind(self) -> pulumi.Input[builtins.str]:
        """
        Log kind name of this subscription.
        """
        return pulumi.get(self, "kind")

    @kind.setter
    def kind(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "kind", value)

    @property
    @pulumi.getter(name="streamId")
    def stream_id(self) -> pulumi.Input[builtins.str]:
        """
        Id of the target Log data platform stream.
        """
        return pulumi.get(self, "stream_id")

    @stream_id.setter
    def stream_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "stream_id", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)


@pulumi.input_type
class _LogSubscriptionState:
    def __init__(__self__, *,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 created_at: Optional[pulumi.Input[builtins.str]] = None,
                 engine: Optional[pulumi.Input[builtins.str]] = None,
                 kind: Optional[pulumi.Input[builtins.str]] = None,
                 ldp_service_name: Optional[pulumi.Input[builtins.str]] = None,
                 operation_id: Optional[pulumi.Input[builtins.str]] = None,
                 resource_name: Optional[pulumi.Input[builtins.str]] = None,
                 resource_type: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 stream_id: Optional[pulumi.Input[builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering LogSubscription resources.
        :param pulumi.Input[builtins.str] cluster_id: Cluster ID.
        :param pulumi.Input[builtins.str] created_at: Creation date of the subscription.
        :param pulumi.Input[builtins.str] engine: The database engine for which you want to manage a subscription. To get a full list of available engine visit. [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases).
        :param pulumi.Input[builtins.str] kind: Log kind name of this subscription.
        :param pulumi.Input[builtins.str] ldp_service_name: Name of the destination log service.
        :param pulumi.Input[builtins.str] operation_id: Identifier of the operation.
        :param pulumi.Input[builtins.str] resource_name: Name of subscribed resource, where the logs come from.
        :param pulumi.Input[builtins.str] resource_type: Type of subscribed resource, where the logs come from.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.str] stream_id: Id of the target Log data platform stream.
        :param pulumi.Input[builtins.str] updated_at: Last update date of the subscription.
        """
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if engine is not None:
            pulumi.set(__self__, "engine", engine)
        if kind is not None:
            pulumi.set(__self__, "kind", kind)
        if ldp_service_name is not None:
            pulumi.set(__self__, "ldp_service_name", ldp_service_name)
        if operation_id is not None:
            pulumi.set(__self__, "operation_id", operation_id)
        if resource_name is not None:
            pulumi.set(__self__, "resource_name", resource_name)
        if resource_type is not None:
            pulumi.set(__self__, "resource_type", resource_type)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if stream_id is not None:
            pulumi.set(__self__, "stream_id", stream_id)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Cluster ID.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Creation date of the subscription.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def engine(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The database engine for which you want to manage a subscription. To get a full list of available engine visit. [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases).
        """
        return pulumi.get(self, "engine")

    @engine.setter
    def engine(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "engine", value)

    @property
    @pulumi.getter
    def kind(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Log kind name of this subscription.
        """
        return pulumi.get(self, "kind")

    @kind.setter
    def kind(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kind", value)

    @property
    @pulumi.getter(name="ldpServiceName")
    def ldp_service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Name of the destination log service.
        """
        return pulumi.get(self, "ldp_service_name")

    @ldp_service_name.setter
    def ldp_service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ldp_service_name", value)

    @property
    @pulumi.getter(name="operationId")
    def operation_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Identifier of the operation.
        """
        return pulumi.get(self, "operation_id")

    @operation_id.setter
    def operation_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "operation_id", value)

    @property
    @pulumi.getter(name="resourceName")
    def resource_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Name of subscribed resource, where the logs come from.
        """
        return pulumi.get(self, "resource_name")

    @resource_name.setter
    def resource_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_name", value)

    @property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Type of subscribed resource, where the logs come from.
        """
        return pulumi.get(self, "resource_type")

    @resource_type.setter
    def resource_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_type", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter(name="streamId")
    def stream_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Id of the target Log data platform stream.
        """
        return pulumi.get(self, "stream_id")

    @stream_id.setter
    def stream_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "stream_id", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Last update date of the subscription.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_at", value)


@pulumi.type_token("ovh:CloudProjectDatabase/logSubscription:LogSubscription")
class LogSubscription(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 engine: Optional[pulumi.Input[builtins.str]] = None,
                 kind: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 stream_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Creates a log subscription for a cluster associated with a public cloud project.

        ## Example Usage

        Create a log subscription for a database.

        ```python
        import pulumi
        import pulumi_ovh as ovh

        stream = ovh.Dbaas.get_logs_output_graylog_stream(service_name="ldp-xx-xxxxx",
            title="my stream")
        db = ovh.CloudProjectDatabase.get_database(service_name="XXX",
            engine="YYY",
            id="ZZZ")
        subscription = ovh.cloud_project_database.LogSubscription("subscription",
            service_name=db.service_name,
            engine=db.engine,
            cluster_id=db.id,
            stream_id=stream.id,
            kind="customer_logs")
        ```

        ## Import

        OVHcloud Managed clusters logs subscription can be imported using the `service_name`, `engine`, `cluster_id` and `id` of the subscription, separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:CloudProjectDatabase/logSubscription:LogSubscription sub service_name/engine/cluster_id/id
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cluster_id: Cluster ID.
        :param pulumi.Input[builtins.str] engine: The database engine for which you want to manage a subscription. To get a full list of available engine visit. [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases).
        :param pulumi.Input[builtins.str] kind: Log kind name of this subscription.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.str] stream_id: Id of the target Log data platform stream.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: LogSubscriptionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a log subscription for a cluster associated with a public cloud project.

        ## Example Usage

        Create a log subscription for a database.

        ```python
        import pulumi
        import pulumi_ovh as ovh

        stream = ovh.Dbaas.get_logs_output_graylog_stream(service_name="ldp-xx-xxxxx",
            title="my stream")
        db = ovh.CloudProjectDatabase.get_database(service_name="XXX",
            engine="YYY",
            id="ZZZ")
        subscription = ovh.cloud_project_database.LogSubscription("subscription",
            service_name=db.service_name,
            engine=db.engine,
            cluster_id=db.id,
            stream_id=stream.id,
            kind="customer_logs")
        ```

        ## Import

        OVHcloud Managed clusters logs subscription can be imported using the `service_name`, `engine`, `cluster_id` and `id` of the subscription, separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:CloudProjectDatabase/logSubscription:LogSubscription sub service_name/engine/cluster_id/id
        ```

        :param str resource_name: The name of the resource.
        :param LogSubscriptionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(LogSubscriptionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 engine: Optional[pulumi.Input[builtins.str]] = None,
                 kind: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 stream_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = LogSubscriptionArgs.__new__(LogSubscriptionArgs)

            if cluster_id is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_id'")
            __props__.__dict__["cluster_id"] = cluster_id
            if engine is None and not opts.urn:
                raise TypeError("Missing required property 'engine'")
            __props__.__dict__["engine"] = engine
            if kind is None and not opts.urn:
                raise TypeError("Missing required property 'kind'")
            __props__.__dict__["kind"] = kind
            __props__.__dict__["service_name"] = service_name
            if stream_id is None and not opts.urn:
                raise TypeError("Missing required property 'stream_id'")
            __props__.__dict__["stream_id"] = stream_id
            __props__.__dict__["created_at"] = None
            __props__.__dict__["ldp_service_name"] = None
            __props__.__dict__["operation_id"] = None
            __props__.__dict__["resource_name"] = None
            __props__.__dict__["resource_type"] = None
            __props__.__dict__["updated_at"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["ldpServiceName"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(LogSubscription, __self__).__init__(
            'ovh:CloudProjectDatabase/logSubscription:LogSubscription',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cluster_id: Optional[pulumi.Input[builtins.str]] = None,
            created_at: Optional[pulumi.Input[builtins.str]] = None,
            engine: Optional[pulumi.Input[builtins.str]] = None,
            kind: Optional[pulumi.Input[builtins.str]] = None,
            ldp_service_name: Optional[pulumi.Input[builtins.str]] = None,
            operation_id: Optional[pulumi.Input[builtins.str]] = None,
            resource_name_: Optional[pulumi.Input[builtins.str]] = None,
            resource_type: Optional[pulumi.Input[builtins.str]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            stream_id: Optional[pulumi.Input[builtins.str]] = None,
            updated_at: Optional[pulumi.Input[builtins.str]] = None) -> 'LogSubscription':
        """
        Get an existing LogSubscription resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cluster_id: Cluster ID.
        :param pulumi.Input[builtins.str] created_at: Creation date of the subscription.
        :param pulumi.Input[builtins.str] engine: The database engine for which you want to manage a subscription. To get a full list of available engine visit. [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases).
        :param pulumi.Input[builtins.str] kind: Log kind name of this subscription.
        :param pulumi.Input[builtins.str] ldp_service_name: Name of the destination log service.
        :param pulumi.Input[builtins.str] operation_id: Identifier of the operation.
        :param pulumi.Input[builtins.str] resource_name_: Name of subscribed resource, where the logs come from.
        :param pulumi.Input[builtins.str] resource_type: Type of subscribed resource, where the logs come from.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.str] stream_id: Id of the target Log data platform stream.
        :param pulumi.Input[builtins.str] updated_at: Last update date of the subscription.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _LogSubscriptionState.__new__(_LogSubscriptionState)

        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["engine"] = engine
        __props__.__dict__["kind"] = kind
        __props__.__dict__["ldp_service_name"] = ldp_service_name
        __props__.__dict__["operation_id"] = operation_id
        __props__.__dict__["resource_name"] = resource_name_
        __props__.__dict__["resource_type"] = resource_type
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["stream_id"] = stream_id
        __props__.__dict__["updated_at"] = updated_at
        return LogSubscription(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[builtins.str]:
        """
        Cluster ID.
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[builtins.str]:
        """
        Creation date of the subscription.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def engine(self) -> pulumi.Output[builtins.str]:
        """
        The database engine for which you want to manage a subscription. To get a full list of available engine visit. [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases).
        """
        return pulumi.get(self, "engine")

    @property
    @pulumi.getter
    def kind(self) -> pulumi.Output[builtins.str]:
        """
        Log kind name of this subscription.
        """
        return pulumi.get(self, "kind")

    @property
    @pulumi.getter(name="ldpServiceName")
    def ldp_service_name(self) -> pulumi.Output[builtins.str]:
        """
        Name of the destination log service.
        """
        return pulumi.get(self, "ldp_service_name")

    @property
    @pulumi.getter(name="operationId")
    def operation_id(self) -> pulumi.Output[builtins.str]:
        """
        Identifier of the operation.
        """
        return pulumi.get(self, "operation_id")

    @property
    @pulumi.getter(name="resourceName")
    def resource_name(self) -> pulumi.Output[builtins.str]:
        """
        Name of subscribed resource, where the logs come from.
        """
        return pulumi.get(self, "resource_name")

    @property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> pulumi.Output[builtins.str]:
        """
        Type of subscribed resource, where the logs come from.
        """
        return pulumi.get(self, "resource_type")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter(name="streamId")
    def stream_id(self) -> pulumi.Output[builtins.str]:
        """
        Id of the target Log data platform stream.
        """
        return pulumi.get(self, "stream_id")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[builtins.str]:
        """
        Last update date of the subscription.
        """
        return pulumi.get(self, "updated_at")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetPostgresSqlConnectionPoolResult',
    'AwaitableGetPostgresSqlConnectionPoolResult',
    'get_postgres_sql_connection_pool',
    'get_postgres_sql_connection_pool_output',
]

@pulumi.output_type
class GetPostgresSqlConnectionPoolResult:
    """
    A collection of values returned by getPostgresSqlConnectionPool.
    """
    def __init__(__self__, cluster_id=None, database_id=None, id=None, mode=None, name=None, port=None, service_name=None, size=None, ssl_mode=None, uri=None, user_id=None):
        if cluster_id and not isinstance(cluster_id, str):
            raise TypeError("Expected argument 'cluster_id' to be a str")
        pulumi.set(__self__, "cluster_id", cluster_id)
        if database_id and not isinstance(database_id, str):
            raise TypeError("Expected argument 'database_id' to be a str")
        pulumi.set(__self__, "database_id", database_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if mode and not isinstance(mode, str):
            raise TypeError("Expected argument 'mode' to be a str")
        pulumi.set(__self__, "mode", mode)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if port and not isinstance(port, int):
            raise TypeError("Expected argument 'port' to be a int")
        pulumi.set(__self__, "port", port)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if size and not isinstance(size, int):
            raise TypeError("Expected argument 'size' to be a int")
        pulumi.set(__self__, "size", size)
        if ssl_mode and not isinstance(ssl_mode, str):
            raise TypeError("Expected argument 'ssl_mode' to be a str")
        pulumi.set(__self__, "ssl_mode", ssl_mode)
        if uri and not isinstance(uri, str):
            raise TypeError("Expected argument 'uri' to be a str")
        pulumi.set(__self__, "uri", uri)
        if user_id and not isinstance(user_id, str):
            raise TypeError("Expected argument 'user_id' to be a str")
        pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> builtins.str:
        """
        See Argument Reference above
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter(name="databaseId")
    def database_id(self) -> builtins.str:
        """
        Database ID for a database that belongs to the Database cluster given above.
        """
        return pulumi.get(self, "database_id")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def mode(self) -> builtins.str:
        """
        Connection mode to the connection pool Available modes:
        """
        return pulumi.get(self, "mode")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        See Argument Reference above
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def port(self) -> builtins.int:
        """
        Port of the connection pool.
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        """
        See Argument Reference above
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def size(self) -> builtins.int:
        """
        Size of the connection pool.
        """
        return pulumi.get(self, "size")

    @property
    @pulumi.getter(name="sslMode")
    def ssl_mode(self) -> builtins.str:
        """
        Ssl connection mode for the pool.
        """
        return pulumi.get(self, "ssl_mode")

    @property
    @pulumi.getter
    def uri(self) -> builtins.str:
        """
        Connection URI to the pool.
        """
        return pulumi.get(self, "uri")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> builtins.str:
        """
        Database user authorized to connect to the pool, if none all the users are allowed.
        """
        return pulumi.get(self, "user_id")


class AwaitableGetPostgresSqlConnectionPoolResult(GetPostgresSqlConnectionPoolResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPostgresSqlConnectionPoolResult(
            cluster_id=self.cluster_id,
            database_id=self.database_id,
            id=self.id,
            mode=self.mode,
            name=self.name,
            port=self.port,
            service_name=self.service_name,
            size=self.size,
            ssl_mode=self.ssl_mode,
            uri=self.uri,
            user_id=self.user_id)


def get_postgres_sql_connection_pool(cluster_id: Optional[builtins.str] = None,
                                     name: Optional[builtins.str] = None,
                                     service_name: Optional[builtins.str] = None,
                                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPostgresSqlConnectionPoolResult:
    """
    Use this data source to get information about a connection pool of a postgresql cluster associated with a public cloud project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    test_pool = ovh.CloudProjectDatabase.get_postgres_sql_connection_pool(service_name="XXX",
        cluster_id="YYY",
        name="ZZZ")
    pulumi.export("testPool", {
        "serviceName": test_pool.service_name,
        "clusterId": test_pool.cluster_id,
        "name": test_pool.name,
        "databaseId": test_pool.database_id,
        "mode": test_pool.mode,
        "size": test_pool.size,
        "port": test_pool.port,
        "sslMode": test_pool.ssl_mode,
        "uri": test_pool.uri,
        "userId": test_pool.user_id,
    })
    ```


    :param builtins.str cluster_id: Cluster ID.
    :param builtins.str name: Name of the Connection pool.
    :param builtins.str service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    """
    __args__ = dict()
    __args__['clusterId'] = cluster_id
    __args__['name'] = name
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:CloudProjectDatabase/getPostgresSqlConnectionPool:getPostgresSqlConnectionPool', __args__, opts=opts, typ=GetPostgresSqlConnectionPoolResult).value

    return AwaitableGetPostgresSqlConnectionPoolResult(
        cluster_id=pulumi.get(__ret__, 'cluster_id'),
        database_id=pulumi.get(__ret__, 'database_id'),
        id=pulumi.get(__ret__, 'id'),
        mode=pulumi.get(__ret__, 'mode'),
        name=pulumi.get(__ret__, 'name'),
        port=pulumi.get(__ret__, 'port'),
        service_name=pulumi.get(__ret__, 'service_name'),
        size=pulumi.get(__ret__, 'size'),
        ssl_mode=pulumi.get(__ret__, 'ssl_mode'),
        uri=pulumi.get(__ret__, 'uri'),
        user_id=pulumi.get(__ret__, 'user_id'))
def get_postgres_sql_connection_pool_output(cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                                            name: Optional[pulumi.Input[builtins.str]] = None,
                                            service_name: Optional[pulumi.Input[builtins.str]] = None,
                                            opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPostgresSqlConnectionPoolResult]:
    """
    Use this data source to get information about a connection pool of a postgresql cluster associated with a public cloud project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    test_pool = ovh.CloudProjectDatabase.get_postgres_sql_connection_pool(service_name="XXX",
        cluster_id="YYY",
        name="ZZZ")
    pulumi.export("testPool", {
        "serviceName": test_pool.service_name,
        "clusterId": test_pool.cluster_id,
        "name": test_pool.name,
        "databaseId": test_pool.database_id,
        "mode": test_pool.mode,
        "size": test_pool.size,
        "port": test_pool.port,
        "sslMode": test_pool.ssl_mode,
        "uri": test_pool.uri,
        "userId": test_pool.user_id,
    })
    ```


    :param builtins.str cluster_id: Cluster ID.
    :param builtins.str name: Name of the Connection pool.
    :param builtins.str service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    """
    __args__ = dict()
    __args__['clusterId'] = cluster_id
    __args__['name'] = name
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:CloudProjectDatabase/getPostgresSqlConnectionPool:getPostgresSqlConnectionPool', __args__, opts=opts, typ=GetPostgresSqlConnectionPoolResult)
    return __ret__.apply(lambda __response__: GetPostgresSqlConnectionPoolResult(
        cluster_id=pulumi.get(__response__, 'cluster_id'),
        database_id=pulumi.get(__response__, 'database_id'),
        id=pulumi.get(__response__, 'id'),
        mode=pulumi.get(__response__, 'mode'),
        name=pulumi.get(__response__, 'name'),
        port=pulumi.get(__response__, 'port'),
        service_name=pulumi.get(__response__, 'service_name'),
        size=pulumi.get(__response__, 'size'),
        ssl_mode=pulumi.get(__response__, 'ssl_mode'),
        uri=pulumi.get(__response__, 'uri'),
        user_id=pulumi.get(__response__, 'user_id')))
